@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: Class1.h 1106 2012-06-18 23:50:58Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -28,8 +28,12 @@
 /*
  * EIA/TIA-578 (Class 1) Modem Driver.
  */
+#include "config.h"
 #include "FaxModem.h"
 #include "FaxParams.h"
+#if defined(HAVE_SSL)
+#include "sslfax.h"
+#endif
 
 class HDLCFrame;
 
@@ -42,6 +46,7 @@ typedef struct {
     u_short	sr;	// T.30 DCS signalling rate
     u_char	mod;	// modulation technique
     bool	ok;	// true if modem is capable
+    u_short	num;	// distinct, incremental numbering
 } Class1Cap;
 #define	HasShortTraining(c) \
     ((c)->mod == V17 && ((c)->value & 1) && (c)[1].ok)
@@ -63,12 +68,23 @@ protected:
     bool	hadV17Trouble;		// indicates failure due to V.17 problems
     bool	batchingError;		// indicates failure due to batching protocol
     bool	jbigSupported;		// whether or not JBIG is supported in this mode
+    bool	senderHasV17Trouble;	// whether or not a sender has trouble with V.17
+    bool	senderSkipsV29;		// whether or not a sender skips over V.29 usage
+    bool	senderConfusesRTN;	// whether or not a sender properly handles RTN
+    bool	senderConfusesPIN;	// whether or not a sender properly handles PIN
+    bool	senderFumblesECM;	// whether or not a sender properly handles ECM
+    bool	sentRTN;		// whether or not we recently sent RTN
+    int		dataSent;		// how much data the sender transmitted
+    int		dataMissed;		// how much data from the sender was missed
+    int		pageDataMissed;		// how much data from the sender was missed on this page
     const u_char* frameRev;		// HDLC frame bit reversal table
     fxStr	lid;			// encoded local id string
     fxStr	pwd;			// transmit password
     fxStr	sub;			// transmit subaddress
+    u_int	storedBitrate;		// stored modem bitrate for fallback from SSL Fax
     Class1Cap	xmitCaps[15];		// modem send capabilities
     Class1Cap	recvCaps[15];		// modem recv capabilities
+    u_int	capsUsed;		// which modulations+bitrates were used in the session
     const Class1Cap* curcap;		// capabilities being used
     u_int	discap;			// DIS signalling rate capabilities
     u_int	prevPage;		// count of previous pages received
@@ -80,8 +96,8 @@ protected:
     bool	silenceHeard;		// indicates whether the last command was +FRS
     time_t	lastMCF;		// indicates the time of the last MCF signal
     u_int	lastPPM;		// last PPM during receive
+    u_int	prevPPM;		// previous PPM during receive
     bool	sendCFR;		// received TCF was not confirmed
-    u_int	ecmPage;		// page number for ECM frame
     u_short	ecmBitPos;		// bit position to populate on ecmByte
     u_int	ecmByte;		// pending byte to add to ecmBlock
     u_short	ecmOnes;		// count of consecutive ones for adding zero bits
@@ -94,6 +110,7 @@ protected:
     u_int	frameNumber;		// frame sequence number of ecmFrame in ecmBlock
     u_short	blockNumber;		// block sequence number of ecmBlock in page
     int		imagefd;		// file descriptor for raw image
+    bool	triggerInterrupt;	// flag to trigger procedural interrupt
 
     static const u_int modemPFMCodes[8];// map T.30 FCF to Class 2 PFM
     static const u_int modemPPMCodes[8];// map T.30 FCF to Class 2 PPM
@@ -121,6 +138,26 @@ protected:
     u_short	controlV34Rate;	// rate indication for control channel
     fxStr	ctrlFrameRcvd;	// unexpected control channel frame received
 
+// special features
+    bool	useSSLFax;	// whether or not we're doing SSL Fax
+    bool	isSSLFax;	// whether or not SSL Fax handshaking succeeded
+    bool	wasSSLFax;	// whether or not SSL Fax handshaking succeeded before
+    bool	suppressSSLFax;	// whether or not to suspend SSL Fax for this session
+    bool	usingSSLFaxProxy; // whether or not an SSL Fax proxy is used
+    fxStr	remoteCSAinfo;	// remote CSA string (host:port)
+    u_char	remoteCSAType;	// remote CSA type
+    u_char	sslFaxPastData[11]; // most recent 11 bytes of received SSL Fax data
+#if defined(HAVE_SSL)
+    SSLFaxProcess sslFaxProcess;// contains data about SSL Fax process
+#endif
+    fxStr	sslFaxPasscode;	// passcode for SSL Fax
+    short	sslRcvCC;	// # bytes pending in rcvBuf
+    short	sslRcvNext;	// next available byte in rcvBuf
+    u_short	sslRcvBit;	// pending bit of rcvNext to send
+    int		sslGotByte;	// byte held for bit destruction
+    bool	sslSawBlockEnd;	// whether DLE+ETX has been seen
+    bool	sslWatchModem;	// whether or not SSL Fax should watch for modem activity
+
 // modem setup stuff
     virtual bool setupModem(bool isSend = true);
     virtual bool setupClass1Parameters();
@@ -130,13 +167,13 @@ protected:
     void	checkReceiverDIS(Class2Params&);
     bool	dropToNextBR(Class2Params&);
     bool	raiseToNextBR(Class2Params&);
-    bool	sendTraining(Class2Params&, int, Status& eresult);
+    bool	sendTraining(Class2Params&, int, fxStr& emsg);
     bool	sendTCF(const Class2Params&, u_int ms);
-    bool	sendPage(TIFF* tif, Class2Params&, u_int, u_int, Status& eresult, bool cover);
-    bool	sendPageData(u_char* data, u_int cc, const u_char* bitrev, bool ecm, Status& eresult);
-    bool	sendRTC(Class2Params params, u_int ppmcmd, uint32 rowsperstrip, Status& eresult);
-    bool	sendPPM(u_int ppm, HDLCFrame& mcf, Status& eresult);
-    bool	decodePPM(const fxStr& pph, u_int& ppm, Status& eresult);
+    bool	sendPage(TIFF* tif, Class2Params&, u_int, u_int, fxStr& emsg);
+    bool	sendPageData(u_char* data, u_int cc, const u_char* bitrev, bool ecm, fxStr& emsg);
+    bool	sendRTC(Class2Params params, u_int ppmcmd, uint32_t rowsperstrip, fxStr& emsg);
+    bool	sendPPM(u_int ppm, HDLCFrame& mcf, fxStr& emsg);
+    bool	decodePPM(const fxStr& pph, u_int& ppm, fxStr& emsg);
 // reception support
     const AnswerMsg* findAnswer(const char*);
     bool	recvIdentification(
@@ -145,14 +182,15 @@ protected:
 		    u_int f3, const fxStr& nsf,
 		    u_int f4, const fxStr& id,
 		    u_int f5, FaxParams& dics,
-		    u_int timer, bool notransmit, Status& eresult);
+		    u_int timer, bool notransmit, fxStr& emsg);
     bool	recvDCSFrames(HDLCFrame& frame);
-    bool	recvTraining();
-    bool	recvPPM(int& ppm, Status& eresult);
-    bool	recvPageData(TIFF*, Status& eresult);
-    bool	raiseRecvCarrier(bool& dolongtrain, Status& eresult);
+    bool	recvTraining(bool respond = true);
+    bool	recvPPM(int& ppm, fxStr& emsg);
+    bool	recvPageData(TIFF*, fxStr& emsg);
+    bool	raiseRecvCarrier(bool& dolongtrain, fxStr& emsg);
     void	recvData(TIFF*, u_char* buf, int n);
     void	processDCSFrame(const HDLCFrame& frame);
+    void	processNewCapabilityUsage();
     void	abortPageRecv();
 // miscellaneous
     enum {			// Class 1-specific AT responses
@@ -162,42 +200,47 @@ protected:
     virtual ATResponse atResponse(char* buf, long ms = 30*1000);
     virtual bool waitFor(ATResponse wanted, long ms = 30*1000);
     virtual bool atCmd(const fxStr& cmd, ATResponse = AT_OK, long ms = 30*1000);
-    bool	switchingPause(Status& eresult, u_int times = 1);
+    bool	switchingPause(fxStr& emsg, u_int times = 1);
     void	encodeTSI(fxStr& binary, const fxStr& ascii);
+    void	encodeCSA(fxStr& binary, const fxStr& ascii, bool haspasscode);
     void	encodeNSF(fxStr& binary, const fxStr& ascii);
     const fxStr& decodeTSI(fxStr& ascii, const HDLCFrame& binary);
+    const fxStr& decodeCSA(fxStr& ascii, const HDLCFrame& binary);
     void	encodePWD(fxStr& binary, const fxStr& ascii);
     const fxStr& decodePWD(fxStr& ascii, const HDLCFrame& binary);
     const Class1Cap* findSRCapability(u_short sr, const Class1Cap[]);
     const Class1Cap* findBRCapability(u_short br, const Class1Cap[]);
     static bool isCapable(u_int sr, FaxParams& dis);
+    int		getModemChar(long ms = 0, bool isquery = false);
+    int		getModemBit(long ms = 0);
+    int		getModemDataChar();
 // class 1 HDLC frame support
     bool	transmitFrame(fxStr& signal);
     bool	transmitFrame(u_char fcf, bool lastFrame = true);
     bool	transmitFrame(u_char fcf, FaxParams& dcs_caps, bool lastFrame = true);
     bool	transmitFrame(u_char fcf, const fxStr&, bool lastFrame=true);
-    bool	transmitFrame(u_char fcf, const u_char* code, const fxStr&, bool lastFrame=true);
+    bool	transmitFrame(u_char fcf, const u_char* code, const u_char* features, const fxStr&, bool lastFrame=true);
     bool	transmitData(int br, u_char* data, u_int cc,
 		    const u_char* bitrev, bool eod);
     bool	sendFrame(u_char fcf, bool lastFrame = true);
     bool	sendFrame(u_char fcf, FaxParams& dcs_caps, bool lastFrame = true);
     bool	sendFrame(u_char fcf, const fxStr&, bool lastFrame = true);
-    bool	sendFrame(u_char fcf, const u_char* code, const fxStr&, bool lastFrame = true);
+    bool	sendFrame(u_char fcf, const u_char* code, const u_char* features, const fxStr&, bool lastFrame = true);
     bool	sendRawFrame(HDLCFrame& frame);
     bool	sendClass1Data(const u_char* data, u_int cc, const u_char* bitrev, bool eod, long ms);
     bool	sendClass1ECMData(const u_char* data, u_int cc,
-		     const u_char* bitrev, bool eod, u_int ppmcmd, Status& eresult);
-    bool	recvFrame(HDLCFrame& frame, u_char dir, long ms = 10*1000, bool readPending = false, bool docrp = true, bool usehooksensitivity = true);
+		     const u_char* bitrev, bool eod, u_int ppmcmd, fxStr& emsg);
+    bool	recvFrame(HDLCFrame& frame, u_char dir, long ms = 10*1000, bool readPending = false, bool docrp = true, bool usehooksensitivity = true, u_int echofcf = 0, bool docng = false, bool handlestutter = false);
     bool	recvTCF(int br, HDLCFrame&, const u_char* bitrev, long ms);
     bool	recvRawFrame(HDLCFrame& frame);
     bool	recvECMFrame(HDLCFrame& frame);
     bool        waitForDCEChannel(bool awaitctrl);
     bool        renegotiatePrimary(bool constrain);
     bool	syncECMFrame();
-    void	abortPageECMRecv(TIFF* tif, const Class2Params& params, u_char* block, u_int fcount, u_short seq, bool pagedataseen);
-    bool	recvPageECMData(TIFF* tif, const Class2Params& params, Status& eresult);
+    void	abortPageECMRecv(TIFF* tif, const Class2Params& params, u_char* block, u_int fcount, u_short seq, bool pagedataseen, fxStr& emsg);
+    bool	recvPageECMData(TIFF* tif, Class2Params& params, fxStr& emsg);
     void	blockData(u_int byte, bool flag);
-    bool	blockFrame(const u_char* bitrev, bool lastframe, u_int ppmcmd, Status& eresult);
+    bool	blockFrame(const u_char* bitrev, bool lastframe, u_int ppmcmd, fxStr& emsg);
     bool	endECMBlock();
     void	abortReceive();
     void	traceHDLCFrame(const char* direction, const HDLCFrame& frame, bool isecm = false);
@@ -210,31 +253,33 @@ public:
     void	hangup();
 
 // send support
-    bool	sendSetup(FaxRequest&, const Class2Params&, Status& eresult);
-    CallStatus	dialResponse(Status& eresult);
-    FaxSendStatus getPrologue(Class2Params&, bool&, Status& eresult, u_int&);
+    bool	sendSetup(FaxRequest&, const Class2Params&, fxStr& emsg);
+    CallStatus	dialResponse(fxStr& emsg);
+    FaxSendStatus getPrologue(Class2Params&, bool&, fxStr&, u_int&, bool docng = false);
     void	sendBegin();
+    void	getDataStats(FaxSetup* setupinfo);
     void	sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     FaxSendStatus sendPhaseB(TIFF* tif, Class2Params&, FaxMachineInfo&,
-		    fxStr& pph, Status& eresult, u_int& batched, PageType pt);
+		    fxStr& pph, fxStr& emsg, u_int& batched);
     void	sendEnd();
     void	sendAbort();
 
 // receive support
-    CallType	answerCall(AnswerType, Status& eresult, const char* number);
+    CallType	answerCall(AnswerType, fxStr& emsg, const char* number, bool doSecondAnswer);
     FaxParams	modemDIS() const;
     bool	setupReceive();
-    bool	recvBegin(Status& eresult);
-    bool	recvEOMBegin(Status& eresult);
-    bool	recvPage(TIFF*, u_int& ppm, Status& eresult, const fxStr& id);
-    bool	recvEnd(Status& eresult);
+    bool	recvBegin(FaxSetup* setupinfo, fxStr& emsg);
+    bool	recvEOMBegin(FaxSetup* setupinfo, fxStr& emsg);
+    bool	performProceduralInterrupt(bool disableECM, bool positive, fxStr& emsg);
+    bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg, const fxStr& id, u_int maxPages);
+    bool	recvEnd(FaxSetup* setupinfo, fxStr& emsg);
     void	recvAbort();
     void	pokeConfig(bool isSend);
 
 // polling support
-    bool	requestToPoll(Status& eresult);
+    bool	requestToPoll(fxStr&);
     bool	pollBegin(const fxStr& cig, const fxStr& sep, const fxStr& pwd,
-		    Status& eresult);
+		    fxStr& emsg);
 
 // miscellaneous
     bool	faxService(bool enableV34, bool enableV17);	// switch to fax mode (send)
