@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: Class20.h 2 2005-11-11 21:32:03Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -33,7 +33,7 @@
 class Class20Modem : public Class2Modem {
 protected:
 // transmission support
-    bool	sendPage(TIFF* tif, u_int pageChop, bool cover);
+    bool	sendPage(TIFF* tif, u_int pageChop);
     bool	pageDone(u_int ppm, u_int& ppr);
 
     void	abortDataTransfer();
