@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: FaxMachineInfo.h 1106 2012-06-18 23:50:58Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -54,6 +54,23 @@ private:
     bool	supportsMMR;		// handles Group 4
     bool	hasV34Trouble;		// has difficulty with V.34
     bool	hasV17Trouble;		// has difficulty with V.17
+    bool	senderHasV17Trouble;	// sender has difficulty with V.17
+    bool	senderSkipsV29;		// sender skips over V.29 usage
+    bool	senderConfusesRTN;	// sender misbehaves with RTN
+    bool	senderConfusesPIN;	// sender misbehaves with PIN
+    bool	senderFumblesECM;	// sender misbehaves with ECM
+    u_int	senderDataSent;		// amount of session data sent by sender
+    u_int	senderDataSent1;	// amount of previous session data sent by sender
+    u_int	senderDataSent2;	// amount of previous, previous session data sent by sender
+    u_int	senderDataMissed;	// amount of session data missed from sender
+    u_int	senderDataMissed1;	// amount of previous session data missed from sender
+    u_int	senderDataMissed2;	// amount of previous, previous session data missed from sender
+    u_int	dataSent;		// amount of session data sent to destination
+    u_int	dataSent1;		// amount of previous session data sent to destination
+    u_int	dataSent2;		// amount of previous, previous session data sent to destination
+    u_int	dataMissed;		// amount of session data missed to destination
+    u_int	dataMissed1;		// amount of previous session data missed to destination
+    u_int	dataMissed2;		// amount of previous, previous session data missed to destination
     bool	supportsPostScript;	// handles Adobe NSF protocol
     bool	supportsBatching;	// handles batching (EOM) protocol
     bool	calledBefore;		// successfully called before
@@ -98,6 +115,23 @@ public:
     bool getSupportsMMR() const;
     bool getHasV34Trouble() const;
     bool getHasV17Trouble() const;
+    bool getSenderHasV17Trouble() const;
+    bool getSenderSkipsV29() const;
+    bool getSenderConfusesRTN() const;
+    bool getSenderConfusesPIN() const;
+    bool getSenderFumblesECM() const;
+    int getSenderDataSent() const;
+    int getSenderDataSent1() const;
+    int getSenderDataSent2() const;
+    int getSenderDataMissed() const;
+    int getSenderDataMissed1() const;
+    int getSenderDataMissed2() const;
+    int getDataSent() const;
+    int getDataSent1() const;
+    int getDataSent2() const;
+    int getDataMissed() const;
+    int getDataMissed1() const;
+    int getDataMissed2() const;
     bool getSupportsPostScript() const;
     bool getSupportsBatching() const;
     bool getCalledBefore() const;
@@ -120,6 +154,23 @@ public:
     void setSupportsMMR(bool);
     void setHasV34Trouble(bool);
     void setHasV17Trouble(bool);
+    void setSenderHasV17Trouble(bool);
+    void setSenderSkipsV29(bool);
+    void setSenderConfusesRTN(bool);
+    void setSenderConfusesPIN(bool);
+    void setSenderFumblesECM(bool);
+    void setSenderDataSent(int);
+    void setSenderDataSent1(int);
+    void setSenderDataSent2(int);
+    void setSenderDataMissed(int);
+    void setSenderDataMissed1(int);
+    void setSenderDataMissed2(int);
+    void setDataSent(int);
+    void setDataSent1(int);
+    void setDataSent2(int);
+    void setDataMissed(int);
+    void setDataMissed1(int);
+    void setDataMissed2(int);
     void setSupportsPostScript(bool);
     void setSupportsBatching(bool);
     void setCalledBefore(bool);
@@ -154,6 +205,40 @@ inline bool FaxMachineInfo::getHasV34Trouble() const
     { return hasV34Trouble; }
 inline bool FaxMachineInfo::getHasV17Trouble() const
     { return hasV17Trouble; }
+inline bool FaxMachineInfo::getSenderHasV17Trouble() const
+    { return senderHasV17Trouble; }
+inline bool FaxMachineInfo::getSenderSkipsV29() const
+    { return senderSkipsV29; }
+inline bool FaxMachineInfo::getSenderConfusesRTN() const
+    { return senderConfusesRTN; }
+inline bool FaxMachineInfo::getSenderConfusesPIN() const
+    { return senderConfusesPIN; }
+inline bool FaxMachineInfo::getSenderFumblesECM() const
+    { return senderFumblesECM; }
+inline int FaxMachineInfo::getSenderDataSent() const
+    { return senderDataSent; }
+inline int FaxMachineInfo::getSenderDataSent1() const
+    { return senderDataSent1; }
+inline int FaxMachineInfo::getSenderDataSent2() const
+    { return senderDataSent2; }
+inline int FaxMachineInfo::getSenderDataMissed() const
+    { return senderDataMissed; }
+inline int FaxMachineInfo::getSenderDataMissed1() const
+    { return senderDataMissed1; }
+inline int FaxMachineInfo::getSenderDataMissed2() const
+    { return senderDataMissed2; }
+inline int FaxMachineInfo::getDataSent() const
+    { return dataSent; }
+inline int FaxMachineInfo::getDataSent1() const
+    { return dataSent1; }
+inline int FaxMachineInfo::getDataSent2() const
+    { return dataSent2; }
+inline int FaxMachineInfo::getDataMissed() const
+    { return dataMissed; }
+inline int FaxMachineInfo::getDataMissed1() const
+    { return dataMissed1; }
+inline int FaxMachineInfo::getDataMissed2() const
+    { return dataMissed2; }
 inline bool FaxMachineInfo::getSupportsPostScript() const
     { return supportsPostScript; }
 inline bool FaxMachineInfo::getSupportsBatching() const
