@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: FaxModem.h 1108 2012-06-26 03:56:56Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -28,6 +28,8 @@
 /*
  * Class 1, 2, and 2.0 Fax Modem Driver Interface.
  */
+#include <stdint.h>
+
 #include "ClassModem.h"
 #include "Class2Params.h"
 #include "tiffio.h"
@@ -45,8 +47,17 @@ class FaxServer;
 //     if there were a portable way to refer to them!
 typedef unsigned int RTNHandling;       // RTN signal handling method 
 typedef unsigned int BadPageHandling;	// bad page (received) handling method 
+typedef unsigned int MissedPageHandling;// missed page (received) handling method 
 typedef unsigned int JBIGSupport;	// JBIG support available
-typedef unsigned int PageType;
+typedef struct {
+    bool	senderFumblesECM;	// if sender misbehaves with ECM
+    bool	senderConfusesRTN;	// if sender misbehaves with RTN
+    bool	senderConfusesPIN;	// if sender misbehaves with PIN
+    bool	senderSkipsV29;		// if sender skips V.29 usage
+    bool	senderHasV17Trouble;	// if we have trouble understanding sender's V.17
+    int		senderDataSent;		// how much data the sender transmitted
+    int		senderDataMissed;	// how much data which the sender transmitted was missing or corrupt
+} FaxSetup;
 
 /*
  * This is an abstract class that defines the interface to
@@ -61,16 +72,17 @@ class FaxModem : public ClassModem, public G3Decoder {
 private:
     FaxServer&	server;		// server for getting to device
 // transmit tag line support
-    u_int	pageNumber;	// current session page number
-    u_int	pageNumberOfJob;// current session page number of Job
-    u_int	pageNumberSkipped;// current skipped page count
-    u_int	pageNumberCovered;// current cover page count
+    u_int	pageNumber;	// current transmit page number
+    u_int	pageNumberOfJob;// current transmit page number of Job
+    u_int	pageNumberOfCall;// current transmit page number of call
+    u_int	noCountCoverPages; // number of no-count cover pages
     FaxFont*	tagLineFont;	// font for imaging tag line
     u_int	tagLineSlop;	// extra space reserved for tag line re-encoding
     fxStr	tagLine;	// tag line formatted with transmit time
+    fxStr	tagLineLocale;	// locale setting for tagline
     u_int	tagLineFields;	// number of fields in the tag line
 
-    void	setupTagLine(const FaxRequest&, const fxStr& tagLineFmt);
+    void	setupTagLine(const FaxRequest&, const fxStr& tagLineFmt, const fxStr& locale, const fxStr& tz);
 // phase c data receive & copy quality checking
     u_int	cblc;		// current count of consecutive bad lines
     bool	lastRowBad;	// last decoded row was bad
@@ -83,17 +95,17 @@ private:
     u_char*	recvRow;	// current receive row raster
     u_char*	recvPageStart;	// pointer to start of page buffer
     tiff_offset_t*	savedWriteOff;	// file offset at start of page data
-    tiff_bytecount_t*	savedStripByteCounts;	// byte counts at start of page data
+    TIFFSTRIPBYTECOUNTS*	savedStripByteCounts;	// byte counts at start of page data
     int		decodedPixels;	// number of pixels decoded with error
     int		decoderFd[2];	// file descriptors for the decoder pipe
     int		counterFd[2];	// file descriptors for the counter pipe
     pid_t	decoderPid;	// process id for the decoding process
     u_char	parserBuf[16];	// buffer used for parsing JBIG and JPEG
-    u_long	parserCount[3];	// counters used in parsing JBIG and JPEG
+    u_long	parserCount[4];	// counters used in parsing JBIG and JPEG
     int		imagefd;	// file descriptor for image file
 
-    void	flushEncodedData(TIFF*, tstrip_t, const u_char*, u_int);
-    void	flushRawData(TIFF*, tstrip_t, const u_char*, u_int);
+    void	flushEncodedData(TIFF*, tstrip_t, const u_char*, u_int, fxStr& emsg);
+    void	flushRawData(TIFF*, tstrip_t, const u_char*, u_int, fxStr& emsg);
     void	invalidCode(const char* type, int x);
     void	badPixelCount(const char* type, int got, int expected);
     void	badDecodingState(const char* type, int x);
@@ -111,7 +123,7 @@ protected:
     FaxRequest*	curreq;		// current job request being processed
     int		bytePending;	// pending byte on recv
     fxStackBuffer* recvBuf;	// raw recv data for when copy quality disabled
-    uint32	group3opts;	// for writing received TIFF
+    uint32_t	group3opts;	// for writing received TIFF
     Class2Params params;	// current session params
     u_int       recvFillOrder;  // bit order of recvd data (ModemConfig & autodetected)
     u_int       sendFillOrder;  // bit order of sent data (ModemConfig & autodetected)
@@ -121,40 +133,45 @@ protected:
     FaxModem(FaxServer&, const ModemConfig&);
 
 // miscellaneous
-    void	countPage(PageType);
-    int		getPageNumber();
+    bool	getSeenRTC();
+    void	countPage();
+    int		getPageNumberOfCall();
     void	recvTrace(const char* fmt, ...);
     void	copyQualityTrace(const char* fmt, ...);
     void	traceModemParams();
     void	traceFCF(const char* dir, u_int fcf);
     void	parseJPEGStream(u_char c);
-    void	fixupJPEG(TIFF* tif);
+    void	fixupJPEG(TIFF* tif, fxStr& emsg);
     void	parseJBIGStream(u_char c);
     void	parseJBIGBIH(u_char* buf);
     void	clearSDNORMCount();
 // server-related stuff
     bool	getHDLCTracing();
     bool	getECMTracing();
+    bool	getSSLFaxTracing();
+    void	setSSLFaxFd(int fd);
+    int		getModemFd();
+    int		getSSLFaxFd();
+    bool	getSSLFaxConnection();
     FaxSendStatus sendSetupParams(TIFF*, Class2Params&,
-		    FaxMachineInfo&, Status&);
+		    FaxMachineInfo&, fxStr&);
     void	recvTSI(const fxStr&);
     void	recvPWD(const fxStr&);
     void	recvSUB(const fxStr&);
-    void	recvNSF(const NSF&);
+    const u_char*	recvNSF(const NSF&);
     void	recvCSI(const fxStr&);
     void	recvDCS(const Class2Params&);
     void	recvSetupTIFF(TIFF* tif, long group3opts, int fillOrder, const fxStr& id);
     void	recvStartPage(TIFF* tif);
     void	recvResetPage(TIFF* tif);
     u_int	decodePageChop(const fxStr& pph, const Class2Params&);
-    bool	decodePPM(const fxStr& pph, u_int& ppm, Status& eresult);
-    void	notifyPageSent(TIFF*, PageType pt);
+    bool	decodePPM(const fxStr& pph, u_int& ppm, fxStr& emsg);
+    void	notifyPageSent(TIFF*);
 // phase c data receive & copy quality checking
     bool	recvPageDLEData(TIFF* tif, bool checkQuality,
-		    const Class2Params& params, Status& eresult);
+		    const Class2Params& params, fxStr& emsg);
     void	setupStartPage(TIFF* tif, const Class2Params& params);
     void	recvEndPage(TIFF* tif, const Class2Params& params);
-    void	writeECMData(TIFF*, u_char*, u_int, const Class2Params&, u_short);
     void	resetLineCounts();
     void	initializeDecoder(const Class2Params&);
     virtual void abortPageRecv() = 0;
@@ -168,18 +185,20 @@ protected:
 // tag line support
     bool	setupTagLineSlop(const Class2Params&);
     u_int	getTagLineSlop() const;
-    u_char*	imageTagLine(u_char* buf, u_int fillorder, const Class2Params&, u_long& totdata, PageType p);
+    u_char*	imageTagLine(u_char* buf, u_int fillorder, const Class2Params&, u_long& totdata);
 /*
  * Correct if neccessary Phase C (T.4/T.6) data (remove extra RTC/EOFB etc.)
  */
     void	correctPhaseCData(u_char* buf, u_long& pBufSize,
-                                  u_int fillorder, const Class2Params& params, uint32& rows);
+                                  u_int fillorder, const Class2Params& params, uint32_t& rows);
 /*
  * Convert Phase C data...
  */
     u_char*	convertPhaseCData(u_char* buf, u_long& totdata, u_int fillorder,
-                            const Class2Params& params, const Class2Params& newparams, uint32& rows);
+                            const Class2Params& params, const Class2Params& newparams, uint32_t& rows);
 public:
+    void	recvRecordEmsg(TIFF* tif, fxStr& emsg);
+    void	writeECMData(TIFF*, u_char*, u_int, const Class2Params&, u_short, fxStr& emsg);
     enum {			// FaxModem::RTNHandling
         RTN_RETRANSMIT = 0,         // retransmit page after RTN until MCF/MPS
         RTN_GIVEUP     = 1,         // immediately abort
@@ -191,23 +210,22 @@ public:
 	BADPAGE_DCN     = 1,	// send DCN, expect a disconnection
 	BADPAGE_RTNSAVE = 2	// send RTN, but save the page
     };
+    enum {			// FaxModem::MissedPageHandling
+	MISSEDPAGE_RTN  = 0,	// send RTN, expect a retransmission from Phase B
+	MISSEDPAGE_DCN  = 1,	// send DCN, expect a disconnection
+	MISSEDPAGE_CFR  = 2,	// send CFR, expect a retransmission from Phase C
+	MISSEDPAGE_PIN  = 3	// send PIN, expect a retransmission from Phase B after procedural interrupt
+    };
     enum {			// FaxModem::JBIGSupport
 	JBIG_NONE = 0,		    // no JBIG support
 	JBIG_RECV = 1,		    // receive-only JBIG support
 	JBIG_SEND = 2,		    // send-only JBIG support
 	JBIG_FULL = 3		    // full JBIG support
     };
-    enum {
-	PAGE_NORMAL	= 0,
-	PAGE_COVER	= 1,
-	PAGE_SKIP	= 2
-    };
-
 
     virtual ~FaxModem();
 
     bool isFaxModem() const;
-    bool isCountingSkippedPages () const;
 
 // configuration controls
     virtual void setLID(const fxStr& number) = 0;
@@ -222,6 +240,7 @@ public:
     virtual bool supportsPageLength(u_int l) const;
     virtual bool supportsPolling() const;
     virtual bool supportsECM(u_int ec = 0) const;
+    virtual bool supportsJPEG(u_int jp = 0) const;
 
     virtual int selectSignallingRate(int br) const;
     u_int getBestSignallingRate() const;
@@ -229,6 +248,8 @@ public:
     u_int getBestScanlineTime() const;
     virtual int selectScanlineTime(int st) const;
 
+    u_int getNoCountCoverPages();
+
     u_int getVRes() const;
     u_int getBestDataFormat() const;
     u_int getBestPageWidth() const;
@@ -239,7 +260,7 @@ public:
     /*
      * Fax send protocol.  The expected sequence is:
      *
-     * if (faxService() && sendSetup(req, params, emsg) && dial(number, emsg) == OK) {
+     * if (faxService() && sendSetup(req, params, emsg) && dial(number, origin, emsg) == OK) {
      *	  sendBegin();
      *	  if (getPrologue() == send_ok and parameters acceptable) {
      *	     select send parameters
@@ -258,14 +279,14 @@ public:
      * single T.30 document.
      */
     virtual bool faxService(bool enableV34, bool enableV17) = 0;
-    virtual bool sendSetup(FaxRequest&, const Class2Params& dis, Status&
-		    eresult);
+    virtual bool sendSetup(FaxRequest&, const Class2Params& dis, fxStr& emsg);
+    virtual bool setOrigin(FaxRequest&);
     virtual void sendBegin();
     virtual FaxSendStatus getPrologue(Class2Params&,
-	bool& hasDoc, Status& eresult, u_int& batched) = 0;
+	bool& hasDoc, fxStr& emsg, u_int& batched, bool docng = false) = 0;
     virtual void sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     virtual FaxSendStatus sendPhaseB(TIFF*, Class2Params&, FaxMachineInfo&,
-	fxStr& pph, Status& eresult, u_int& batched, PageType = PAGE_NORMAL) = 0;
+	fxStr& pph, fxStr& emsg, u_int& batched) = 0;
     virtual void sendEnd();
     virtual void sendAbort() = 0;
     // query interfaces for optional state
@@ -301,10 +322,11 @@ public:
      * }
      */
     virtual bool setupReceive() = 0;
-    virtual bool recvBegin(Status& eresult);
-    virtual bool recvEOMBegin(Status& eresult);
-    virtual bool recvPage(TIFF*, u_int& ppm, Status& result, const fxStr& id) = 0;
-    virtual bool recvEnd(Status& eresult) = 0;
+    virtual bool recvBegin(FaxSetup* setupinfo, fxStr& emsg);
+    virtual void getDataStats(FaxSetup* setupinfo);
+    virtual bool recvEOMBegin(FaxSetup* setupinfo, fxStr& emsg);
+    virtual bool recvPage(TIFF*, u_int& ppm, fxStr& em, const fxStr& id, u_int maxPages) = 0;
+    virtual bool recvEnd(FaxSetup* setupinfo, fxStr& emsg) = 0;
     virtual void recvAbort() = 0;
     virtual void recvSucceeded();
     virtual void pokeConfig(bool isSend) = 0;
@@ -329,9 +351,9 @@ public:
      *
      * (i.e. it's just like a receive operation.)
      */
-    virtual bool requestToPoll(Status& eresult) = 0;
+    virtual bool requestToPoll(fxStr& emsg) = 0;
     virtual bool pollBegin(
 	const fxStr& cig, const fxStr& sep, const fxStr& pwd,
-	Status& eresult);
+	fxStr& emsg);
 };
 #endif /* _FAXMODEM_ */
