@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: FaxServer.h 756 2008-01-12 20:00:18Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -31,7 +31,6 @@
 #include "ModemServer.h"
 #include "FaxRecvInfo.h"
 #include "Array.h"
-#include "FaxRequest.h"
 
 class FaxAcctInfo;
 
@@ -53,6 +52,7 @@ private:
     fxStr	recvTSI;		// sender's TSI
     fxStr	hostname;		// host on which fax is received
     u_int	recvPages;		// count of received pages
+    pid_t	waitNotifyPid;		// pid of last notification process
 // send+receive stats
     time_t	connTime;		// time connected to peer
     time_t	fileStart;		// starting time for file transmit
@@ -60,6 +60,7 @@ private:
     time_t	pageTransferTime;	// transfer time for last page
     u_int	npages;			// # pages sent/received
     fxStr	batchid;		// Batch ID, for session logs
+    u_int	formatSize[2];		// combined byte sizes for comparing 1D and 2D encodings
 
     friend class FaxModem;
 
@@ -67,22 +68,23 @@ private:
 
 // FAX transmission protocol support
     void	sendFax(FaxRequest& fax, FaxMachineInfo&, const fxStr& number, u_int&);
-    bool	sendClientCapabilitiesOK(FaxRequest&, FaxMachineInfo&, Status& result);
+    bool	sendClientCapabilitiesOK(FaxRequest&, FaxMachineInfo&, fxStr&);
     bool	sendFaxPhaseB(FaxRequest&, FaxItem&, FaxMachineInfo&, u_int, bool);
     void	sendPoll(FaxRequest& fax, bool remoteHasDoc);
     FaxSendStatus sendSetupParams(TIFF*,
-		    Class2Params&, const FaxMachineInfo&, Status& result);
+		    Class2Params&, const FaxMachineInfo&, fxStr&);
     FaxSendStatus sendSetupParams1(TIFF*,
-		    Class2Params&, const FaxMachineInfo&, Status& result);
+		    Class2Params&, const FaxMachineInfo&, fxStr&);
     void	sendFailed(FaxRequest& fax,
-		    FaxSendStatus, const Status& result, u_int tts = 0);
+		    FaxSendStatus, const char* notice, u_int tts = 0);
 // FAX reception support
     int		getRecvFile(fxStr& qfile, fxStr& emsg);
-    TIFF*	setupForRecv(FaxRecvInfo&, FaxRecvInfoArray&, Status& eresult);
-    bool	recvDocuments(TIFF*, FaxRecvInfo&, FaxRecvInfoArray&, Status& eresult);
-    bool	recvFaxPhaseD(TIFF* tif, FaxRecvInfo&, u_int& ppm, Status& eresult);
+    TIFF*	setupForRecv(FaxRecvInfo&, FaxRecvInfoArray&, fxStr& emsg);
+    bool	recvDocuments(TIFF*, FaxRecvInfo&, FaxRecvInfoArray&,
+		    FaxSetup* setupinfo, fxStr& emsg);
+    bool	recvFaxPhaseD(TIFF* tif, FaxRecvInfo&, u_int& ppm, fxStr& emsg);
     bool	pollFaxPhaseB(const fxStr& sep, const fxStr& pwd,
-		    FaxRecvInfoArray&, Status& eresult);
+		    FaxRecvInfoArray&, fxStr& emsg);
 protected:
     FaxServer(const fxStr& deviceName, const fxStr& devID);
 
@@ -95,7 +97,7 @@ protected:
     void	setLocalIdentifier(const fxStr& lid);
 
     void	sendFax(FaxRequest&, FaxMachineInfo&, FaxAcctInfo&, u_int&, bool);
-    bool	recvFax(const CallID& callid, Status& eresult);
+    bool	recvFax(const CallID& callid, FaxMachineInfo clientInfo, fxStr& emsg);
 
     time_t	getFileTransferTime() const;
     time_t	getPageTransferTime() const;
@@ -106,7 +108,7 @@ protected:
 // notification interfaces overridden in derived class
     virtual void notifyCallPlaced(const FaxRequest&);
     virtual void notifyConnected(const FaxRequest&);
-    virtual void notifyPageSent(FaxRequest&, const char*, PageType pt);
+    virtual void notifyPageSent(FaxRequest&, const char*);
     virtual void notifyDocumentSent(FaxRequest&, u_int index);
     virtual void notifyPollRecvd(FaxRequest&, FaxRecvInfo&);
     virtual void notifyPollDone(FaxRequest&, u_int index);
@@ -114,6 +116,7 @@ protected:
     virtual void notifyPageRecvd(TIFF* tif, FaxRecvInfo&, int ppm);
     virtual void notifyDocumentRecvd(FaxRecvInfo& req);
     virtual void notifyRecvDone(FaxRecvInfo& req);
+    virtual bool processTSIRecvdCmd(FaxRecvInfo&, fxStr&);
 public:
     virtual ~FaxServer();
 
