@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: MemoryDecoder.h 686 2007-11-04 01:45:30Z faxguy $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -36,7 +36,7 @@ private:
     u_int	width;
     u_int	byteWidth;
     u_long	cc;
-    uint32	rows;
+    uint32_t	rows;
     u_int	fillorder;
     bool	is2D, isG4;
     u_char*	endOfData;	// used by cutExtraRTC
@@ -57,14 +57,14 @@ public:
     void fixFirstEOL();
     u_char* cutExtraRTC();
     u_char* cutExtraEOFB();
-    u_char* encodeTagLine (u_long* raster, u_int th, u_int slop);
+    u_char* encodeTagLine (u_long* raster, u_int th, u_int slop, uint32_t scanlines = 0, bool addLines = false, bool onBottom = false);
     u_char* convertDataFormat(const Class2Params& params);
 
     void scanPageForBlanks(u_int fillorder, const Class2Params& params);
     const u_char* getEndOfPage()			{ return endOfData; }
     u_int getLastBlanks()				{ return nblanks; }
     u_long getCC()					{ return cc; }
-    uint32 getRows()					{ return rows; }
+    uint32_t getRows()					{ return rows; }
 };
 
 #endif
