@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: ModemConfig.h 1105 2012-06-14 17:57:49Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -30,15 +30,19 @@
  */
 #include "FaxConfig.h"
 #include "FaxModem.h"
+#include "config.h"
 
 #include "Array.h"
-#include "StrArray.h"
 
 class id_config
 {
     public:
 	fxStr	pattern;
 	int	answerlength;
+	bool	display;
+	fxStr	label;
+	bool	record;
+	fxStr	type;
 
 	int compare (const id_config* n) const
 	{
@@ -47,7 +51,7 @@ class id_config
 
 };
 
-fxDECLARE_ObjArray(IDConfArray, id_config);
+fxDECLARE_ObjArray(IDConfArray, id_config)
 
 struct ModemConfig : public FaxConfig {
 private:
@@ -59,6 +63,7 @@ private:
     u_int	getDataFormat(const char* value);
     u_int       getRTNHandling(const char* cp);
     u_int       getBadPageHandling(const char* cp);
+    u_int       getMissedPageHandling(const char* cp);
     u_int       getJBIGSupport(const char* cp);
     ECMType	getECMType(const char* cp);
 
@@ -83,7 +88,11 @@ public:
     fxStr	type;			// modem type
     fxStr	resetCmds;		// extra modem reset commands for start of initialization
     fxStr	readyCmds;		// extra modem reset commands for end of initialization
+    fxStr	CEDCmd;			// cmd for signaling CED
+    fxStr	CNGCmd;			// cmd for signaling CNG
     fxStr	dialCmd;		// cmd for dialing (%s for number)
+    fxStr	setOriginCmd;		// cmd for setting the origination id (%s for name, %d for number)
+    fxStr	answerAgainCmd;		// cmd for answering after a missed answer command
     fxStr	answerAnyCmd;		// cmd for answering unknown call type
     fxStr	answerDataCmd;		// cmd for answering data call
     fxStr	answerFaxCmd;		// cmd for answering fax call
@@ -116,6 +125,7 @@ public:
     fxStr	answerDataBeginCmd;	// cmd to start inbound data session
     fxStr	answerFaxBeginCmd;	// cmd to start inbound fax session
     fxStr	answerVoiceBeginCmd;	// cmd to start inbound voice session
+    fxStr	secondAnswerCmd;	// cmd to restart after abort to first answer cmd
     fxStr	sendBeginCmd;		// cmd to start outbound session
     fxStr	recvSuccessCmd;		// cmd for after successful reception
     fxStr	class0Cmd;		// cmd for setting Class 0
@@ -154,6 +164,10 @@ public:
     fxStr	class1EOPWaitCmd;	// cmd to stop and wait prior to EOP
     fxStr	class1SwitchingCmd;	// after recv HDLC and before sending
     fxStr	class1MsgRecvHackCmd;	// cmd to avoid +FCERROR before image
+    bool	class1SSLFaxSupport;	// to enable/disable SSL Fax
+    fxStr	class1SSLFaxInfo;	// host:port information for "SSL Fax" server feature
+    fxStr	class1SSLFaxCert;	// SSL encryption certificate for "SSL Fax" feature
+    fxStr	class1SSLFaxProxy;	// password@host:port information for "SSL Fax" proxy
     fxStr	class1TCFRecvHackCmd;	// cmd to avoid +FCERROR before TCF
     u_int	class1TCFRecvTimeout;	// timeout receiving TCF
     u_int	class1RecvAbortOK;	// if non-zero, OK sent after recv abort
@@ -162,6 +176,8 @@ public:
     u_int	class1Resolutions;	// resolutions support
     u_int	class1FrameOverhead;	// overhead bytes in received frames
     u_int	class1RecvIdentTimer;	// timeout receiving initial identity
+    u_int	class1SSLFaxClientTimeout; // SSL Fax timeout waiting for the client connection
+    u_int	class1SSLFaxServerTimeout; // SSL Fax timeout waiting for the server connection
     u_int	class1TCFMaxNonZero;	// non-zero threshold for TCF check
     u_int	class1TCFMinRun;	// min length of zero run for TCF check
     u_int	class1TCFMinRunECMMod;	// modify min length in ECM by this factor
@@ -169,6 +185,8 @@ public:
     u_int	class1ECMFrameSize;	// ECM frame size for transmission
     u_int	class1PageLengthSupport;// page length support
     u_int	class1PageWidthSupport;	// page width support
+    u_int	class1RestrictPoorSenders;// restrict senders with poor audio from certain features
+    bool	class1ECMCheckFrameLength;// check frame length and not just CRC
     bool	class1GreyJPEGSupport;	// Greyscale JPEG support
     bool	class1ColorJPEGSupport;	// Full-color JPEG support
     bool	class1ECMSupport;	// support T.30-A ECM
@@ -178,12 +196,15 @@ public:
     bool	class1ValidateV21Frames;// check received FCS values in V.21
     bool	class1ModemHasDLEBug;	// modem doesn't double-up DLEs in V.21
     bool	class1HasRHConnectBug;	// modem reports CONNECT after +FRH=3 to non-V.21-HDLC data
+    bool	class1HasRMHookIndication;	// modem reports ERROR after +FRM=<mod> when on hook
+    bool	class10AutoFallback;	// modem automatically falls back to G3 mode if no ANSam detected
 					// for class 2 and 2.0:
     fxStr	class2Cmd;		// cmd for setting Class 2/2.0
     fxStr	class2DCCQueryCmd;	// cmd to query modem capabilities
     fxStr	class2CQQueryCmd;	// cmd to query copy quality checking
     fxStr	class2BORCmd;		// cmd to set bit order
     fxStr	class2DisableV17Cmd;	// cmd to disable V.17 support
+    fxStr	class2DisableV34Cmd;	// cmd to disable V.34 support
     fxStr	class2RELCmd;		// cmd to enable byte-aligned EOL
     fxStr	class2CQCmd;		// cmd to setup copy quality checking
     fxStr	class2AbortCmd;		// cmd to abort a session
@@ -235,11 +256,12 @@ public:
     u_int	maxConsecutiveBadLines;	// max consecutive bad lines in page
     u_int	minAcceptedLineCount;	// min accepted number of lines in page
     u_int	minSpeed;		// minimum speed for fax transmits
+    u_int	noDialtoneRetries;	// maximum number of attempts to get dialtone
     bool	softRTFCC;		// real-time fax compression conversion (software)
     bool	waitForConnect;		// modem sends multiple answer responses
     fxStr	tagLineFmt;		// format string for tag lines
+    fxStr	tagLineLocale;		// locale for tag lines
     fxStr	tagLineFontFile;	// font file for imaging tag lines
-    fxStr	tagLineCoverNumString;	// format string for tagline cover page numbers
     u_int	recvDataFormat;		// received facsimile data format
     bool	useJobTagLine;		// Use Job tagline or use conf taglineformat
     bool	raiseATCmd;		// whether or not to raise-case the AT commands
@@ -247,12 +269,12 @@ public:
 
     RTNHandling rtnHandling;            // RTN signal handling method
     BadPageHandling badPageHandling;	// bad page (received) handling method
+    MissedPageHandling missedPageHandling;	// missed page (received) handling method
     JBIGSupport	class1JBIGSupport;	// monochrome JBIG support
+    JBIGSupport	class2JBIGSupport;	// monochrome JBIG support
     bool	saveUnconfirmedPages;	// don't delete unconfirmed pages
-    bool	countSkippedPages;	// count (or nor) and notify skipped pages
+    fxStr	tiff2faxCmd;		// for intelligent RTFCC in comparing compression rates
     
-    fxStrArray	playList;		// List of files for ESC_PLAY
-
     					// Distinctive ring data as sequences of DRON/DROF intervals
     struct {
     	int cadence[5];                 // the ring cadence as a five-dimensional vector
