@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: ModemServer.h 1147 2013-02-19 17:55:54Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -64,6 +64,7 @@ private:
     FILE*	statusFile;		// server status file
     bool	deduceComplain;		// if true, complain when can't deduce
     bool	changePriority;		// change process priority by state
+    bool	noFailBusy;		// don't increment dials counters if busy
     bool	delayConfig;		// suppress effects while reading config
     fxStr	dialRulesFile;		// dial string rules filename
     fxStr	commid;			// communication ID
@@ -74,12 +75,16 @@ private:
     ClassModem*	modem;			// modem driver
     Timeout	timer;			// timeout support class
     bool	timeout;		// timeout during i/o operations
+    bool	modemerror;		// modem error during i/o operations
     fxStr	configFile;		// pathname to configuration file
     BaudRate	curRate;		// current termio baud rate
     Parity	curParity;		// current termio parity setting
     u_int	curVMin;		// current termio VMIN setting
     u_int	curVTime;		// current termio VTIME setting
     u_int	setupAttempts;		// consec. failed attempts to init modem
+// SSL Fax stuff
+    int		sslFaxFd;		// listening socket
+    bool	sslFaxConnection;	// whether or not we got an SSL Fax connection
 // buffered i/o stuff
     short	rcvCC;			// # bytes pending in rcvBuf
     short	rcvNext;		// next available byte in rcvBuf
@@ -87,7 +92,21 @@ private:
     int		gotByte;		// byte held for bit destruction
     bool	sawBlockEnd;		// whether DLE+ETX has been seen
     bool	inputBuffered;		// whether or not modem input is buffered
-    u_char	rcvBuf[1024];		// receive buffering
+
+/*
+ * Since the very first HylaFAX (before it was even named such) rcvBuf
+ * was always 1024 bytes.  However, since we usually read from modemFd without 
+ * O_NONBLOCK, attempting to read 1024 bytes from modemFd would introduce
+ * small (~100ms) delays as the read operation would not return as long
+ * as the device's write operation was occuring and the 1024 byte buffer
+ * was not yet filled.  These delays can really impact fax operations because
+ * they are longer than most fax-spec tolerances.  So, we now only use
+ * rcvBuf of 1 byte - and that resolves the short read blocking issue.  The
+ * downside is that the ModemIO tracing is "wordy" with this (using one 
+ * whole line of logging per-byte).  The other upside, though, is that the
+ * timestamps on the session logging are accurate to the millisecond.
+ */
+    u_char	rcvBuf[1];		// receive buffering
 
     friend class ClassModem;
 
@@ -121,7 +140,6 @@ protected:
     };
     ModemServerState state;
     bool	abortCall;		// abort current send/receive
-    Status	abortCallReason;	// reason for abort
 // logging and tracing
     FaxMachineLog* log;			// current log device
 
@@ -136,6 +154,10 @@ protected:
     int		getModemFd();				// XXX
     BaudRate	getModemRate() const;
     virtual fxStr getModemCapabilities() const;
+// low-level SSL Fax interface
+    void	setSSLFaxFd(int fd);
+    int		getSSLFaxFd();
+    bool	getSSLFaxConnection();
 // modem i/o support
     void	timerExpired(long, long);
     void	sendDLEETX();
@@ -144,8 +166,10 @@ protected:
     int		getModemBit(long ms = 0);
     int		getLastByte();
     bool	didBlockEnd();
+    void	setBlockEnd();
     void	resetBlock();
     bool	isModemInput() const;
+    bool	isBusyNoFail() const;
     void	flushModemInput();
     bool	putModem(const void* data, int n, long ms = 0);
     bool	putModem1(const void* data, int n, long ms = 0);
@@ -162,12 +186,12 @@ protected:
     bool	modemStopOutput();
 // modem driver interfaces
     bool	modemWaitForRings(u_short rings, CallType&, CallID&);
-    CallType	modemAnswerCall(AnswerType, Status& eresult, const char* dialnumber = NULL);
+    CallType	modemAnswerCall(AnswerType, fxStr&, const char* dialnumber = NULL, bool doSecondAnswer = false);
     void	modemAnswerCallCmd(CallType);
-    void	modemFlushInput();
+    void	modemFlushInput(bool silent = false);
     void	modemHangup();
 // server state and related control interfaces
-    void	changeState(ModemServerState, long timeout = 0);
+    void	changeState(ModemServerState, long timeout = 0, const char* msg = NULL);
     void	setServerStatus(const char* fmt, ...);
     void	setProcessPriority(ModemServerState s);
 // system logging interfaces
@@ -190,13 +214,14 @@ protected:
     virtual void vdialrulesTrace(const char* fmt, va_list ap);
     const fxStr& getConfigFile() const;
 // call/receive session start+end for controlling logging
-    void	beginSession(const fxStr& number);
+    void	beginSession(const fxStr& number, gid_t uid = 0);
     void	endSession();
 // abort send/receive session
-    virtual void abortSession(Status reason);
+    virtual void abortSession();
     bool	abortRequested();
-    Status	abortReason();
 public:
+    const char* readyStateMsg;
+
     virtual ~ModemServer();
 
     virtual void open();
@@ -218,6 +243,8 @@ public:
 };
 inline ClassModem* ModemServer::getModem()		{ return modem; }
 inline int ModemServer::getModemFd()			{ return modemFd; }
+inline int ModemServer::getSSLFaxFd()			{ return sslFaxFd; }
+inline bool ModemServer::getSSLFaxConnection()		{ return sslFaxConnection; }
 inline int ModemServer::getServerTracing() const
     { return (tracingLevel); }
 inline int ModemServer::getSessionTracing() const
@@ -231,5 +258,7 @@ inline const fxStr& ModemServer::getModemNumber() const
 inline const fxStr& ModemServer::getCommID() const	{ return commid; }
 inline bool ModemServer::isModemInput() const
     { return rcvNext < rcvCC; }
+inline bool ModemServer::isBusyNoFail() const
+    { return noFailBusy; }
 
 #endif /* _ModemServer_ */
