@@ -1,4 +1,4 @@
-/* $Id$ */
+/* $Id: NSF.h 118 2006-03-21 23:57:33Z faxguy $ */
 /* 
  * This file does not exist in the original HylaFAX distribution.
  * Created by Dmitry Bely, April 2000
@@ -39,6 +39,7 @@ class NSF {
     fxStr vendor;
     fxStr model;
     fxStr stationId;
+    u_char* features;
     bool  vendorDecoded;
     bool  stationIdDecoded;
 public:
@@ -56,6 +57,7 @@ public:
     const char* getVendor(){ return (const char*)vendor; }
     const char* getModel(){ return (const char*)model; }
     const char* getStationId(){ return (const char*)stationId; }
+    const u_char* getFeatures(){ return (const u_char*)features; }
 private:
     void clear();
     void loadHexData( const char* hexNSF, bool useHex );
