@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: faxApp.h 469 2007-03-09 22:25:54Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -40,6 +40,7 @@ private:
 
     bool	running;		// server running
     int		faxqfifo;		// cached descriptor to faxq
+    int		ignore_fd;		// ignored FIFO write descriptor
 protected:
     int		openFIFO(const char* fifoName, int mode,
 		    bool okToExist = false);
@@ -79,8 +80,9 @@ public:
 
     static const fxStr quote;
     static const fxStr enquote;
+    fxStr  quoted(const fxStr& s);
 
-    static bool runCmd(const char* cmd, bool changeIDs = false, IOHandler* waiter = NULL);
+    static bool runCmd(const char* cmd, const char* argv[], bool changeIDs = false, IOHandler* waiter = NULL);
 };
 inline bool faxApp::isRunning(void) const	{ return running; }
 
