@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: pageSendApp.h 1147 2013-02-19 17:55:54Z faxguy $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -50,6 +50,7 @@ public:
 private:
 // runtime state
     bool	ready;			// modem ready for use
+    bool	nofailbusy;		// don't increment dials counters on busy
     UUCPLock*	modemLock;		// uucp lockfile handle
     time_t	connTime;		// time connected to peer
 
@@ -87,19 +88,18 @@ private:
     void 	sendPage(FaxRequest&, FaxMachineInfo&, const fxStr&, 
 			const fxStr&, u_int&);	
 // IXO transmission support
-    void	sendIxoPage(FaxRequest&, FaxMachineInfo&, const fxStr&, Status& result, u_int&);
-    bool	sendPagerMsg(FaxRequest&, FaxItem&, const fxStr&, Status& result);
+    void	sendIxoPage(FaxRequest&, FaxMachineInfo&, const fxStr&, fxStr&, u_int&);
+    bool	sendPagerMsg(FaxRequest&, FaxItem&, const fxStr&, fxStr&);
     u_int	getResponse(fxStackBuffer& buf, long secs);
     bool	prepareMsg(FaxRequest&, FaxMachineInfo&, fxStr&);
-    bool	pagePrologue(FaxRequest&, const FaxMachineInfo&, Status& result);
-    bool	pageGoAhead(FaxRequest&, const FaxMachineInfo&, Status& result);
-    bool	pageEpilogue(FaxRequest&, const FaxMachineInfo&, Status& result);
-    void	sendFailed(FaxRequest&, FaxSendStatus, const Status&, u_int = 0);
+    bool	pagePrologue(FaxRequest&, const FaxMachineInfo&, fxStr&);
+    bool	pageGoAhead(FaxRequest&, const FaxMachineInfo&, fxStr&);
+    bool	pageEpilogue(FaxRequest&, const FaxMachineInfo&, fxStr&);
+    void	sendFailed(FaxRequest&, FaxSendStatus, const char*, u_int = 0);
     void	notifyPageSent(FaxRequest& req, u_int fi);
     time_t	getConnectTime() const;
 // UCP transmission support
-    void	sendUcpPage(FaxRequest&, FaxMachineInfo&, const fxStr&, Status& result);
-    bool	sendUcpMsg(FaxRequest&, FaxItem&, const fxStr&, Status& result,
+    void	sendUcpPage(FaxRequest&, FaxMachineInfo&, const fxStr&, fxStr&);    bool	sendUcpMsg(FaxRequest&, FaxItem&, const fxStr&, fxStr&,
 		    FaxMachineInfo&);
 // modem handling
     bool	canLockModem();
