@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: MsgFmt.h 790 2008-02-11 04:12:22Z faxguy $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,6 +32,14 @@
 
 class fxStackBuffer;
 
+struct b64State {
+    u_int	l;			// characters left
+    int		c1;
+    int		c2;
+    int		c3;
+    int		c4;
+};
+
 struct MsgFmt {
     TextCoord	headerStop;		// tab stop for headers
     fxStr	boldFont;		// bold font family name
@@ -52,12 +60,16 @@ struct MsgFmt {
 
     static bool getLine(FILE* fd, fxStackBuffer& buf);
     static fxStr stripComments(const fxStr& s);
+    void copyQP(fxStackBuffer& buf, const char line[], u_int cc);
+    void copyBase64(fxStackBuffer& buf, const char line[], u_int cc, b64State& state);
+    void copyUUDecode(fxStackBuffer& buf, const char line[], u_int);
 
     const fxStr* findHeader(const fxStr& name) const;
     u_int headerCount(void);
     fxStr mapHeader(const fxStr& name);
     void parseHeaders(FILE* fd, u_int& lineno);
-    bool formatHeaders(TextFormat& fmt);
+    void formatHeaders(TextFormat& fmt);
     void showItalic(TextFormat& fmt, const char* cp);
+    void decodeRFC2047(fxStr& s);
 };
 #endif /* _MsgFmt_ */
