@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: HylaFAXServer.h 1108 2012-06-26 03:56:56Z faxguy $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -32,15 +32,33 @@
 #include "StrArray.h"
 #include "FaxRequest.h"
 #include "FaxRecvInfo.h"
+/* SendFaxClient.h must come before manifest.h due to conflicts */
+#include "SendFaxClient.h"
 #include "manifest.h"
 #include "FileCache.h"
 #include "Trace.h"
 #include "Trigger.h"
-#include "StackBuffer.h"
 #include "SystemLog.h"
+#include "FaxHostID.h"
 
 #include "config.h"
 
+#ifdef HAVE_PAM
+extern "C" {
+#include <security/pam_appl.h>
+#include <grp.h>
+}
+#endif // HAVE_PAM
+
+#ifdef HAVE_LDAP
+#include <ldap.h>
+#include <string.h>
+#include <stdlib.h>
+#include <sys/time.h>
+#include <lber.h>
+#endif // HAVE_LDAP
+
+#include <stdint.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <dirent.h>
@@ -48,6 +66,12 @@
 #include <setjmp.h>
 #include <errno.h>
 
+class MySendFaxClient : public SendFaxClient {
+public:
+    MySendFaxClient();
+    ~MySendFaxClient();
+};
+
 /*
  * In-memory copy of a job description file.
  */
@@ -75,23 +99,23 @@ struct RecvInfo : public FaxRecvInfo {
 };
 fxDECLARE_StrKeyDictionary(RecvInfoDict, RecvInfo*)
 
-/*
- * An array of content that can sort on a different key
- */
-class KeyString
- : public fxStr
-{
-    public:
-	KeyString ();
-	KeyString (const fxStr& key, const fxStr& data);
+#define HAVE_PSLEVEL2   false
 
-	int compare (const KeyString* that) const;
-
-    private:
-	fxStr key;
+static struct {
+    const char* name;		// protocol token name
+    bool        supported;	// true if format is supported
+    const char* suffix;		// file suffix
+    FaxSendOp	op;		// associated FaxSendOp value
+    const char* help;		// help string for HELP FORM command
+} formats[] = {
+{ "TIFF", true,          "tif", FaxRequest::send_tiff,		"Tagged Image File Format, Class F only" },
+{ "PS",   true,          "ps",  FaxRequest::send_postscript,	"Adobe PostScript" },
+{ "PS2",  HAVE_PSLEVEL2, "ps",  FaxRequest::send_postscript,	"Adobe PostScript Level II" },
+{ "PCL",  true,          "pcl", FaxRequest::send_pcl,		"HP Printer Control Language (PCL)"},
+{ "PDF",  true,          "pdf", FaxRequest::send_pdf,		"Adobe Portable Document Format" },
 };
-fxDECLARE_ObjArray(KeyStringArray, KeyString);
 
+#define N(a)    (sizeof (a) / sizeof (a[0]))
 
 #ifdef T_USER
 #undef T_USER				// XXX FreeBSD defines this
@@ -112,14 +136,14 @@ enum Token {
     T_ABOR,	 T_ACCT,	T_ADDMODEM,	T_ADDUSER,	T_ADMIN,
     T_ALLO,	 T_ANSWER,	T_APPE,		T_CHMOD,	T_CHOWN,
     T_CONFIG,	 T_CWD, 	T_CDUP,		T_DELE,		T_DELUSER,
-    T_DELMODEM,	 T_DISABLE,	T_ENABLE,	T_EPSV,		T_EPRT,		T_FILEFMT,	T_FILESFMT,	T_FORM,
+    T_DELMODEM,	 T_DISABLE,	T_ENABLE,	T_EPSV,		T_EPRT,		T_FILEFMT,	T_FORM,
     T_HELP,	 T_IDLE,	T_LOCKWAIT,	T_JDELE,	T_JGDELE,	T_JGINTR,
     T_JGKILL,	 T_JGNEW,	T_JGPARM,	T_JGREST,	T_JGRP,
     T_JGSUB,	 T_JGSUSP,	T_JGWAIT,	T_JINTR,	T_JKILL,
-    T_JNEW,	 T_JOB,		T_JOBFMT,	T_JOBSFMT,	T_JPARM,	T_JREST,
+    T_JNEW,	 T_JOB,		T_JOBFMT,	T_JPARM,	T_JREST,
     T_JSUB,	 T_JSUSP,	T_JWAIT,	T_LIST,	 	T_MDTM,
-    T_MODE,	 T_MODEMFMT,	T_MODEMSFMT,	T_NLST,		T_NOOP,		T_PASS,
-    T_PASV,	 T_PORT,	T_PWD,		T_QUIT,		T_RCVFMT,	T_RCVSFMT,
+    T_MODE,	 T_MODEMFMT,	T_NLST,		T_NOOP,		T_PASS,
+    T_PASV,	 T_PORT,	T_PWD,		T_QUIT,		T_RCVFMT,
     T_REIN,	 T_REST,	T_RETP,		T_RETR,		T_RNFR,
     T_RNTO,	 T_SHUT,	T_SITE,		T_SIZE,		T_STAT,
     T_STOR,	 T_STOT,	T_STOU,		T_STRU,		T_SYST,
@@ -129,16 +153,16 @@ enum Token {
      */
     T_ACCTINFO,	 T_BEGBR,	T_BEGST,	T_CHOPTHRESH,	T_CLIENT,
     T_COMMENTS,	 T_COMMID,	T_COVER,	T_DATAFORMAT,	T_DIALSTRING,
-    T_DOCUMENT,	 T_DONEOP,	T_EXTERNAL,	T_FAXNUMBER,	T_FROM_COMPANY,	T_FROM_LOCATION,
-    T_FROM_USER, T_FROM_VOICE,	T_GROUPID,	T_HRES,		T_JOBID,
-    T_JOBINFO,	 T_JOBTYPE,	T_LASTTIME,	T_MAXDIALS,	T_MAXPAGES,
+    T_DOCUMENT,	 T_DONEOP,	T_EXTERNAL,	T_FAXNUMBER,	T_FAXNAME,	T_FROM_COMPANY,	T_FROM_LOCATION,
+    T_FROM_USER, T_FROM_VOICE,	T_GROUPID,	T_HRES,		T_IGNOREMODEMBUSY, T_JOBID,
+    T_JOBINFO,	 T_JOBTYPE,	T_LASTTIME,	T_MAXDIALS,
     T_MAXTRIES,	 T_MINBR,	T_MODEM,	T_NDIALS,	T_NOTIFY,
     T_NOTIFYADDR,T_NPAGES,	T_NTRIES,	T_OWNER,	T_PAGECHOP,
-    T_PAGELENGTH,T_PAGEWIDTH,	T_PAGERANGE,	T_PASSWD,	T_POLL,		T_REGARDING,
-    T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_STATE,	T_STATUS,	T_STATUSCODE, T_ERRORCODE,
-    T_SUBADDR,	 T_TAGLINE,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,
-    T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_TSI,		T_USE_CONTCOVER,
-    T_USE_ECM,	 T_USE_TAGLINE,	T_USE_XVRES,	T_USRKEY,	T_VRES,
+    T_PAGELENGTH,T_PAGEWIDTH,	T_PASSWD,	T_POLL,		T_REGARDING,
+    T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_SKIPPAGES,	T_SKIPPEDPAGES,	T_STATE,	T_STATUS,	T_ERRORCODE,
+    T_SUBADDR,	 T_TAGLINE,	T_TIMEOFDAY,	T_TIMEZONE,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,	T_PROBEONLY,
+    T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_TSI,		T_USE_CONTCOVER, T_NOCOUNTCOVER, T_SERVERDOCOVER,
+    T_USE_ECM,	 T_ECMTYPE,	T_USE_TAGLINE,	T_USE_XVRES,	T_USE_COLOR,	T_USE_SSLFAX,	T_USRKEY,	T_VRES, T_CONNTIME, T_DURATION,
     /*
      * SNPP tokens.
      */
@@ -184,11 +208,6 @@ public:
         u_int HylaFAXServer::*p;
         u_int		 def;
     };
-    struct booltag {
-        const char*	 name;
-        bool HylaFAXServer::*p;
-        bool		 def;
-    };
     static int _debugSleep;
     static fxStrArray	configOptions;		// Pased on the command line
 protected:
@@ -215,6 +234,7 @@ protected:
     fxStr	clientFIFOName;		// client FIFO name
     int		faxqFd;			// faxq FIFO open descriptor
     int		clientFd;		// client FIFO open descriptor
+    int		ignore_fd;		// ignore FIFO write descriptor to avoid EOF
     fxStr	fifoResponse;		// response received to FIFO msg
     u_int	idleTimeout;		// client inactivity timeout
     u_int	maxIdleTimeout;		// upper bound on idle timeout
@@ -222,6 +242,10 @@ protected:
     u_int	maxLockTimeout;		// upper bound on qfile lock timeout
     int		data;			// current data connection (socket)
     int		pdata;			// passive mode data connect (socket)
+    fxStr	jobHostId;		// id of this host for jobid/groupid
+    FaxHostIDArray jobHosts;		// array for other known job hosts
+    MySendFaxClient* jobHostClient;	// client connection for job host
+    int		curJobHost;		// currently-connected job host
     fxStr	hostname;		// name of machine server is running on
     fxStr	hostaddr;		// primary address for hostname
     fxStr	remotehost;		// name of peer's machine
@@ -234,21 +258,36 @@ protected:
     time_t	discTime;		// time to disconnect service
     time_t	denyTime;		// time to deny service
     u_int	jobProtection;		// Protection to use on Jobs
-    bool	publicJobQ;		// Public/protection on recvq?
-    bool	publicRecvQ;		// Public/protection on recvq?
-    bool	allowSorting;		// Allow client to make us sort
+    u_int	recvqProtection;	// Protection to use on Recvq
     /*
      * User authentication and login-related state.
      */
-    fxStr	passwd;			// encrypted user password
-    fxStr	adminwd;		// encrypted passwd for admin privileges
+#ifdef HAVE_PAM
+	bool	pam_chrooted;	// if already chrooted, PAM gets disabled
+#endif
+
+    fxStr	passWd;			// encrypted user password - read from hosts.hfaxd
+    fxStr	adminWd;		// encrypted passwd for admin privileges - read from hosts.hfaxd
+    fxStr	usrPassWd;		// unencrypted user password - read from user
+    fxStr	usrAdminWd;		// unencrypted passwd for admin privileges - read from user
+#ifdef HAVE_LDAP
+    fxStr	ldapServerUri;		// URL for the LDAP Server
+    fxStr	ldapBaseDN;		// LDAP base DN where user objects are found
+    fxStr	ldapReqGroup;		// LDAP group users need to be members of for
+					// fax server access
+    fxStr	ldapBindQuery;		// query format used in LDAP bind
+    fxStr	ldapSearchQuery;	// query format used in LDAP search
+    fxStr	ldapSearchDN;		// DN used in LDAP search
+    fxStr	ldapGroupAttribute;	// LDAP group attribute label
+    u_int	ldapVersion;		// LDAP Protocol Version being used (def. v3)
+#endif
     u_int	uid;			// client's ID
     u_int	loginAttempts;		// number of failed login attempts
     u_int	maxLoginAttempts;	// login failures before server exits
     u_int	adminAttempts;		// number of failed admin attempts
     u_int	maxAdminAttempts;	// admin failures before server exits
     fxStr	the_user;		// name of user
-    fxStr	admingroup;			// name of local user group that is allowed
+	fxStr   admingroup;			// name of local user group that is allowed
 								// to administer the fax server
     IDCache*	idcache;		// fax UID -> name mapping table
     /*
@@ -266,7 +305,6 @@ protected:
     SpoolDir*	cwd;			// current working directory
     fxStrArray	tempFiles;		// files created with STOT
     fxStr	fileFormat;		// format string for directory listings
-    fxStr	fileSortFormat;		// format string for directory listings
     TIFF*	cachedTIFF;		// cached open TIFF file
     /*
      * Parser-related state.
@@ -287,15 +325,15 @@ protected:
     Job		defJob;			// default job state information
     JobDict	jobs;			// non-default jobs
     Job*	curJob;			// current job
+    fxStr	curJobId;		// current job id
+    fxStr	curJobGroupId;		// current job group id
     fxStr	jobFormat;		// job status format string
-    fxStr	jobSortFormat;		// job status format string
     JobDict	blankJobs;		// jobs created during this session but not submitted
     /*
      * Receive queue-related state.
      */
     RecvInfoDict recvq;			// cache of info about received fax
     fxStr	recvFormat;		// received fax status format string
-    fxStr	recvSortFormat;		// received fax status format sort key
     /*
      * Trigger-related state.
      */
@@ -305,7 +343,6 @@ protected:
      * Modem-related state.
      */
     fxStr	modemFormat;		// modem status format string
-    fxStr	modemSortFormat;		// modem status format string
 
     static gid_t faxuid;		// system gid of fax user = our uid
 #if HAS_TM_ZONE
@@ -372,18 +409,14 @@ protected:
     void setFileOwner(const char* filename);
 
     void loginRefused(const char* why);
-
+    bool pamCheck(const char* user=NULL, const char* pass=NULL);
+    bool pamIsAdmin(const char* user=NULL);
+#ifdef HAVE_PAM
+    void pamEnd(pam_handle_t *pamh, int pamret);
+#endif
     bool checkUser(const char*);
-    bool checkPasswd(const char*);
-
-    bool checkuserHosts(FILE*, const char *name);
-    bool checkuserPAM(const char *name);
-
-    bool checkpasswdHosts(const char* passwd);
-    bool checkpasswdPAM(const char* passwd);
-
-    bool isAdminGroup(const char* user=NULL);
-
+    bool checkuser(FILE*, const char *name);
+    bool checkuser(const char *name);
     void login(int code);
     void end_login(void);
     virtual void dologout(int status);
@@ -391,7 +424,7 @@ protected:
     const char* userName(u_int uid);
     bool userID(const char*, u_int& id);
     void fillIDCache(void);
-
+    bool ldapCheck(const char* user, const char* pass);
     bool cvtPasswd(const char* type, const char* pass, fxStr& result);
     bool findUser(FILE* db, const char* user, u_int& newuid);
     bool addUser(FILE* db, const char* user, u_int uid,
@@ -403,7 +436,6 @@ protected:
      */
     static stringtag strings[];
     static numbertag numbers[];
-    static booltag booleans[];
 
     void resetConfig();
     void setupConfig();
@@ -446,7 +478,6 @@ protected:
     void listUnixFile(FILE*, const SpoolDir&, const char*, const struct stat&);
     void makeProt(const struct stat& sb, bool withGrp, char prot[10]);
     void Fprintf(FILE*, const char* fmt, const char*, const struct stat&);
-    void Fprintf(fxStackBuffer&, const char* fmt, const char*, const struct stat&);
 
     void nlstDirectory(FILE* fd, const SpoolDir& sd, DIR* dir);
     void nlstUnixFile(FILE*, const SpoolDir&, const char*, const struct stat&);
@@ -473,6 +504,7 @@ protected:
     bool cmd(Token t);
     bool site_cmd(Token t);
     bool param_cmd(Token t);
+    bool multi_string_param(fxStr&, const char* what = NULL);
     bool string_param(fxStr&, const char* what = NULL);
     bool number_param(long&);
     bool boolean_param(bool&);
@@ -493,7 +525,7 @@ protected:
     bool checkNUMBER(const char* s);
     bool opt_CRLF();
     bool opt_STRING(fxStr& s);
-    bool multi_STRING(fxStr& s);
+    bool multi_STRING(fxStr& s, const char* what = NULL);
     static u_int twodigits(const char* cp, u_int range);
     static u_int fourdigits(const char* cp);
     virtual void syntaxError(const char* msg);
@@ -565,10 +597,11 @@ protected:
     void newJobCmd(void);
     bool newJob(fxStr& emsg);
     Job* findJob(const char* jobid, fxStr& emsg);
-    Job* findJobInMemmory(const char* jobid);
+    Job* findJobInMemory(const char* jobid);
     Job* findJobOnDisk(const char* jobid, fxStr& emsg);
     bool updateJobFromDisk(Job& job);
     void replyCurrentJob(const char* leader);
+    bool setupJobHost(const char* jobid, fxStr& emsg);
     void setCurrentJob(const char* jobid);
     Job* preJobCmd(const char* op, const char* jobid, fxStr& emsg);
     void operateOnJob(const char* jobid, const char* what, const char* op);
@@ -590,7 +623,6 @@ protected:
 
     const char* compactTime(time_t t);
     void Jprintf(FILE* fd, const char* fmt, const Job& job);
-    void Jprintf(fxStackBuffer& buf, const char* fmt, const Job& job);
 
     u_int getJobNumber(fxStr&);
     u_int getDocumentNumber(fxStr&);
@@ -599,11 +631,9 @@ protected:
     RecvInfo* getRecvInfo(const fxStr& qfile, const struct stat& sb);
     const char* compactRecvTime(time_t t);
     void Rprintf(FILE*, const char*, const RecvInfo&, const struct stat&);
-    void Rprintf(fxStackBuffer&, const char*, const RecvInfo&, const struct stat&);
 
     void getServerStatus(const char* fileName, fxStr& status);
     void Mprintf(FILE*, const char*, const ModemConfig&);
-    void Mprintf(fxStackBuffer&, const char*, const ModemConfig&);
 public:
     HylaFAXServer();
     virtual ~HylaFAXServer();
@@ -631,7 +661,7 @@ inline void HylaFAXServer::pushToken(Token t)		{ pushedToken = t; }
  * business seeing.  Also we implement an access
  * control system that is built on top of the
  * normal UNIX protection mechanisms.
- */ 
+ */
 struct SpoolDir {
     const char*	pathname;
     bool adminOnly;	// accessible by unprivileged clients
