@@ -40,6 +40,9 @@ struct Class2Params;
  * convention.  Only bit numbers start at index one.  Byte numbers in this class
  * follow the c convention of the index starting at zero.
  *
+ * Not all capabilties and features are represented by the DIS/DCS bitstring;
+ * most notably, features made available through NSF inspection are not
+ * generally represented in DIS and are, therefore, stored in a separate string.
  */
 class FaxParams
 {
@@ -54,6 +57,8 @@ class FaxParams
 
 	void setBit(int bitNum, bool val);
 	bool isBitEnabled(int bitNum);
+	void setFeature(int bitNum, bool val);
+	bool getFeature(int bitNum);
 
 	u_char getByte(int byteNum) const;
 	bool hasNextByte(int byteNum) const;
@@ -68,6 +73,8 @@ class FaxParams
 	void setupT30(u_char* pBits, int length);
 	void setupT30(u_int dcs_dis, u_int xinfo);
 
+	static const int BITNUM_T37;		//  1;
+	static const int BITNUM_T38;		//  3;
 	static const int BITNUM_V8_CAPABLE;	//  6;
 	static const int BITNUM_FRAMESIZE_DIS;	//  7;
 	static const int BITNUM_T4XMTR;		//  9;
@@ -97,12 +104,17 @@ class FaxParams
 	static const int BITNUM_SEP;		// 47;
 	static const int BITNUM_SUB;		// 49;
 	static const int BITNUM_PWD;		// 50;
+	static const int BITNUM_BFT;		// 53;
 	static const int BITNUM_JPEG;		// 68;
 	static const int BITNUM_FULLCOLOR;	// 69;
 	static const int BITNUM_LETTER_SIZE;	// 76;
 	static const int BITNUM_LEGAL_SIZE;	// 77;
 	static const int BITNUM_JBIG_BASIC;	// 78;
 	static const int BITNUM_JBIG_L0;	// 79;
+	static const int BITNUM_BFT_SIMPLE;	// 99;
+	static const int BITNUM_BFT_EXTENDED;	// 100;
+
+	static const int FEATURE_SSLFAX;	// 1;
 
 	FaxParams& assign (const FaxParams&);
 
@@ -118,6 +130,7 @@ class FaxParams
 	bool validBitNumber(int bitNum);
     
 	u_char m_bits[MAX_BITSTRING_BYTES];
+	u_char features;
 };
 
 inline FaxParams& FaxParams::operator= (const FaxParams& p)
