@@ -1,4 +1,4 @@
-/*	$Id$ */
+/*	$Id: faxdeluser.c 970 2010-01-03 04:54:57Z faxguy $ */
 /*
  * Copyright (c) 1999 Robert Colquhoun
  *
@@ -73,6 +73,7 @@ main(int argc, char** argv)
     if (fd == -1) {
         snprintf(buff, sizeof(buff), "Error cannot open file %s", newhostfile);
         perror(buff);
+	fclose(hf);
         return -1;
     }
     while (fgets(buff, sizeof(buff), hf)) {
@@ -105,7 +106,7 @@ main(int argc, char** argv)
         return -1;
     }
     pw = getpwnam(FAX_USER);
-    if (pw == NULL || chown(hostfile, pw->pw_uid, pw->pw_uid)) {
+    if (pw == NULL || chown(hostfile, pw->pw_uid, pw->pw_gid)) {
         perror("Error writing hosts file");
         return -1;
     }
