@@ -70,6 +70,7 @@
  */
 #define	FCF_SNDR	0x80		// station receiving valid DIS
 #define	FCF_RCVR	0x00		// station receiving valid DIS response
+#define FCF_PRIQ	0x08		// procedural interrupt modifier
 
 // initial identification commands from the called to calling station
 #define	FCF_DIS		0x01		// digital identification signal
@@ -82,12 +83,16 @@
 #define	FCF_NSC		(FCF_NSF|FCF_SNDR) // non-standard facilities cmd (opt)
 #define	FCF_PPW		(0x03|FCF_SNDR)	   // password for polling (opt)
 #define	FCF_SEP		(0x05|FCF_SNDR)	   // selective polling subaddress (opt)
+#define	FCF_PSA		(0x06|FCF_SNDR)	   // polled subaddress (opt)
+#define FCF_CIA		(0x07|FCF_SNDR)    // calling subscriber internet address (opt)
+#define FCF_ISP		(0x08|FCF_SNDR)    // internet selective polling address (opt)
 // responses from transmitter to receiver
 #define	FCF_DCS		(0x40|FCF_DIS)	// digital command signal
 #define	FCF_TSI		(0x40|FCF_CSI)	// transmitting subscriber id (opt)
 #define	FCF_NSS		(0x40|FCF_NSF)	// non-standard facilities setup (opt)
 #define	FCF_PWD		(0x40|0x05)	// password for transmission (opt)
 #define	FCF_SUB		(0x40|0x03)	// routing information for xmit (opt)
+#define FCF_TSA		(0x40|0x06)	// transmitting subscriber internet address (opt)
 
 /*
  * Digital Identification Signal (DIS) definitions.
@@ -275,6 +280,7 @@
 #define	FCF_CFR		0x21		// confirmation to receive
 #define	FCF_FTT		0x22		// failure to train
 #define FCF_CTR		0x23		// response to CTC (Annex A)
+#define FCF_CSA		0x24		// called subscriber internet address (opt)
 
 // post-message commands (from transmitter to receiver)
 #define	FCF_EOM		0x71		// end-of-page, restart phase B on ack
